---
title: PETsARD (/pəˈtɑrd/)
type: page
weight: 0
toc: false
---

<p style="text-align:center">
  隱私強化技術分析、研究與開發
</p>

<p align="center"><img src="/petsard/images/PETsARD-logo.png"></p>

<div style="display: flex; justify-content: center; flex-wrap: nowrap; gap: 10px;">
  <a href="https://www.python.org/"><img src="https://img.shields.io/badge/python-v3.10-blue.svg" alt="Python 3.10"></a>
  <a href="https://www.python.org/"><img src="https://img.shields.io/badge/python-v3.11-blue.svg" alt="Python 3.11"></a>
  <a href="https://github.com/your-username/petsard/graphs/contributors"><img src="https://img.shields.io/badge/contributions-welcome-orange.svg" alt="Contributions welcome"></a>
  <a href="https://pypi.org/project/petsard/"><img src="https://img.shields.io/pypi/status/petsard" alt="PyPI - Status"></a>
</div>

## 探索

{{< cards >}}
{{< card link="docs" title="文件" icon="book-open" >}}
{{< card link="about" title="關於" icon="user" >}}
{{< /cards >}}